package VMOMI::CheckTestType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
